@@ -27,15 +27,15 @@ def get_promoter(args):
         for g in db.all_features(featuretype='gene', order_by="seqid"):
             if g.strand == "+":
                 gene_seq = g.sequence(args.genome, use_strand=True)
-                p_start = g.start - int(args.promoter_length) # transform 1-based to 0-based
+                p_start = g.start - int(args.promoter_length) - 1 # 往前数,和terminator不同需要-1, transform 1-based to 0-based
                 if p_start < 0 :
                     continue
-                p_end = g.start + args.utr5_upper_length      # include first base of TSS, transform 1-based to 0-based
+                p_end = g.start + args.utr5_upper_length - 1      # include first base of TSS, transform 1-based to 0-based
                 promoter = genomeDict[g.chrom][p_start:p_end]
             elif g.strand == "-":
                 gene_seq = g.sequence(args.genome, use_strand=True)
-                p_start = g.end - args.utr5_upper_length
-                p_end = g.end + int(args.promoter_length)
+                p_start = g.end - args.utr5_upper_length - 1 
+                p_end = g.end + int(args.promoter_length) - 1
                 promoter = genomeDict[g.chrom][p_start:p_end].reverse_complement()
             p_start_in_genome = p_start
             p_end_in_genome = p_end
@@ -60,15 +60,15 @@ def get_promoter(args):
             if args.gene in g.id:
                 if g.strand == "+":
                     gene_seq = g.sequence(args.genome, use_strand=True)
-                    p_start = g.start - int(args.promoter_length)
+                    p_start = g.start - int(args.promoter_length) - 1
                     if p_start < 0 :
                         continue
-                    p_end = g.start + args.utr5_upper_length
+                    p_end = g.start + args.utr5_upper_length - 1
                     promoter = genomeDict[g.chrom][p_start:p_end]
                 elif g.strand == "-":
                     gene_seq = g.sequence(args.genome, use_strand=True)
-                    p_start = g.end - args.utr5_upper_length
-                    p_end = g.end + int(args.promoter_length)
+                    p_start = g.end - args.utr5_upper_length - 1
+                    p_end = g.end + int(args.promoter_length) - 1
                     promoter = genomeDict[g.chrom][p_start:p_end].reverse_complement()
                 p_start_in_genome = p_start
                 p_end_in_genome = p_end
@@ -76,8 +76,9 @@ def get_promoter(args):
                                           p_end_in_genome, g.strand, promoter]
                 index += 1
                 promoterSeq = SeqRecord(promoter,id=args.gene, 
-                              description='chrom:%s strand:%s promoter start:%d end:%d length=%d'%(
-                              g.chrom, g.strand, p_start_in_genome, p_end_in_genome, len(promoter)))
+                              description='chrom:%s strand:%s gene:%d-%d promoter:%d-%d length=%d'%(
+                              g.chrom, g.strand, g.start, g.end ,
+                              p_start_in_genome, p_end_in_genome, len(promoter)))
                 if args.print:
                     if args.output_format == 'csv':
                         promoter_seq.to_csv(sys.stdout, sep=',', index=False)
